==> qtjambi-webenginecore-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiWebEngineCore/QWebEngineNotification_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtWebEngineCore/qwebenginenotification.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>
#include <QtGui/qimage.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/QList>
#include <QtCore/qcoreevent.h>
#include <QtCore/qtimer.h>
#include <QtCore/qregexp.h>
#include <QtCore/qthread.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qmetaobject.h>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QWebEngineNotification_0(){
    static int result = QMetaMethod::fromSignal(&QWebEngineNotification::closed).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineNotification::click()const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_click_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::click()const", __qt_this)
        __qt_this->click();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineNotification::close()const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_close_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::close()const", __qt_this)
        __qt_this->close();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineNotification::direction()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_direction_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::direction()const", __qt_this)
        Qt::LayoutDirection __qt_return_value = __qt_this->direction();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::icon()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_icon_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::icon()const", __qt_this)
        QImage __qt_return_value = __qt_this->icon();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::language()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_language_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::language()const", __qt_this)
        QString __qt_return_value = __qt_this->language();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::matches(const QWebEngineNotification*)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_matches_1native_1const_1QWebEngineNotification_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::matches(const QWebEngineNotification*)const", __qt_this)
        const QWebEngineNotification* __qt_other0 = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(other0);
        __java_return_value = __qt_this->matches(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::message()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_message_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::message()const", __qt_this)
        QString __qt_return_value = __qt_this->message();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::origin()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::origin()const", __qt_this)
        QUrl __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::show()const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_show_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::show()const", __qt_this)
        __qt_this->show();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineNotification::tag()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_tag_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::tag()const", __qt_this)
        QString __qt_return_value = __qt_this->tag();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::title()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_title_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::title()const", __qt_this)
        QString __qt_return_value = __qt_this->title();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWebEngineNotification(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QWebEngineNotification>("QWebEngineNotification", "io/qt/webengine/core/QWebEngineNotification");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QWebEngineNotification::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "closed", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QWebEngineNotification_0)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QWebEngineNotification_0()){ // closed()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineNotification::staticMetaObject.indexOfMethod("click()const")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineNotification::staticMetaObject.indexOfMethod("close()const")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineNotification::staticMetaObject.indexOfMethod("show()const")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiWebEngineCore/QWebEngineNotification_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebenginenotification.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtGui/qimage.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QWebEngineNotification_0(){
    static int result = QMetaMethod::fromSignal(&QWebEngineNotification::closed).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineNotification::click()const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_click_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::click()const", __qt_this)
        __qt_this->click();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineNotification::close()const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_close_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::close()const", __qt_this)
        __qt_this->close();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineNotification::direction()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_direction_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::direction()const", __qt_this)
        Qt::LayoutDirection __qt_return_value = __qt_this->direction();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::icon()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_icon_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::icon()const", __qt_this)
        QImage __qt_return_value = __qt_this->icon();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::language()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_language_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::language()const", __qt_this)
        QString __qt_return_value = __qt_this->language();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::matches(const QWebEngineNotification*)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_matches_1native_1const_1QWebEngineNotification_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::matches(const QWebEngineNotification*)const", __qt_this)
        const QWebEngineNotification* __qt_other0 = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(other0);
        __java_return_value = __qt_this->matches(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::message()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_message_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::message()const", __qt_this)
        QString __qt_return_value = __qt_this->message();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::origin()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::origin()const", __qt_this)
        QUrl __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::show()const
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_show_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::show()const", __qt_this)
        __qt_this->show();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineNotification::tag()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_tag_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::tag()const", __qt_this)
        QString __qt_return_value = __qt_this->tag();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineNotification::title()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineNotification_title_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineNotification *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineNotification>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineNotification::title()const", __qt_this)
        QString __qt_return_value = __qt_this->title();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWebEngineNotification(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QWebEngineNotification>("QWebEngineNotification", "io/qt/webengine/core/QWebEngineNotification");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QWebEngineNotification::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "closed", "Lio/qt/core/QObject$Signal0;", 0, __signal_method_indexes_QWebEngineNotification_0)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QWebEngineNotification_0()){ // closed()
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineNotification::staticMetaObject.indexOfMethod("click()const")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineNotification::staticMetaObject.indexOfMethod("close()const")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineNotification::staticMetaObject.indexOfMethod("show()const")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
